@@ -15,6 +15,10 @@
 
 /////////////////////////////////////////////////////////////////////////////
 
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 // Deduce the platform, setting macros of the form DASHER_......
 #include "Platform.h"
 
@@ -34,6 +38,8 @@
 
 #include "myassert.h"
 
+#include "mydebug.h"
+
 #include "Trace.h"
 
 #endif // __include__
