@@ -21,6 +21,10 @@
 
 namespace Dasher {
 
+  ///
+  /// \defgroup Alphabet Alphabet information
+  /// @{
+
   class CAlphabet {
   public:
 
@@ -147,6 +151,10 @@ namespace Dasher {
       return TextMap;
     } 
 
+    const std::string &GetDefaultContext() const {
+      return m_strDefaultContext;
+    }
+
     SGroupInfo *m_pBaseGroup;
     
     
@@ -181,9 +189,13 @@ namespace Dasher {
 
     alphabet_map TextMap;
 
+    std::string m_strDefaultContext;
+
     //    friend class CGroupAdder;
   };
 
+  /// @}
+
   inline symbol CAlphabet::GetParagraphSymbol() const {
     return m_ParagraphSymbol;
   }
