@@ -19,6 +19,10 @@
 
 namespace Dasher {
 
+  ///
+  /// \ingroup LM
+  /// @{
+
   ///
   /// PPM language model
   ///
@@ -36,7 +40,7 @@ namespace Dasher {
     virtual void EnterSymbol(Context context, int Symbol);
     virtual void LearnSymbol(Context context, int Symbol);
 
-    virtual void GetProbs(Context context, std::vector < unsigned int >&Probs, int norm) const;
+    virtual void GetProbs(Context context, std::vector < unsigned int >&Probs, int norm, int iUniform) const;
 
     void dump();
 
@@ -98,6 +102,8 @@ namespace Dasher {
     CPooledAlloc < CPPMContext > m_ContextAlloc;
   };
 
+  /// @}
+
   inline Dasher::CPPMLanguageModel::CPPMnode::CPPMnode(int sym):symbol(sym) {
     child = next = vine = 0;
     count = 1;
