@@ -4,6 +4,7 @@
 #include "LanguageModelling/WordLanguageModel.h"
 #include "LanguageModelling/DictLanguageModel.h"
 #include "LanguageModelling/MixtureLanguageModel.h"
+//#include "LanguageModelling/CTWLanguageModel.h"
 #include "NodeCreationManager.h"
 
 CNodeCreationManager::CNodeCreationManager(Dasher::CDasherInterfaceBase *pInterface, Dasher::CEventHandler *pEventHandler, CSettingsStore *pSettingsStore, bool bGameMode, std::string strGameModeText, Dasher::CAlphIO *pAlphIO) : CDasherComponent(pEventHandler, pSettingsStore) {
@@ -65,9 +66,11 @@ void CNodeCreationManager::GetProbs(CLanguageModel::Context context, std::vector
 
   int uniform_add;
   int nonuniform_norm;
-  int control_space;
+  int control_space = 0;
   int uniform = GetLongParameter(LP_UNIFORM);
 
+  // TODO: Sort this out
+
   if(!GetBoolParameter(BP_CONTROL_MODE)) {
     control_space = 0;
     uniform_add = ((iNorm * uniform) / 1000) / (iSymbols - 2);  // Subtract 2 from no symbols to lose control/root nodes
@@ -79,7 +82,8 @@ void CNodeCreationManager::GetProbs(CLanguageModel::Context context, std::vector
     nonuniform_norm = iNorm - control_space - (iSymbols - 2) * uniform_add;
   }
 
-  m_pLanguageModel->GetProbs(context, Probs, nonuniform_norm);
+  //m_pLanguageModel->GetProbs(context, Probs, iNorm, ((iNorm * uniform) / 1000));
+  m_pLanguageModel->GetProbs(context, Probs, iNorm, 0);
 
 #if _DEBUG
   int iTotal = 0;
@@ -88,7 +92,7 @@ void CNodeCreationManager::GetProbs(CLanguageModel::Context context, std::vector
   DASHER_ASSERT(iTotal == nonuniform_norm);
 #endif
 
-  //  Probs.insert(Probs.begin(), 0);
+    //Probs.insert(Probs.begin(), 0);
 
   for(unsigned int k(1); k < Probs.size(); ++k)
     Probs[k] += uniform_add;
