@@ -73,6 +73,9 @@ void CSettingsStore::SetBoolParameter(int iParameter, bool bValue) {
   // Check that the parameter is in fact in the right spot in the table
   DASHER_ASSERT(iParameter == s_oParamTables.BoolParamTable[iParameter - FIRST_BP].key);
 
+  if(bValue == GetBoolParameter(iParameter))
+    return;
+
   // Set the value
   s_oParamTables.BoolParamTable[iParameter - FIRST_BP].value = bValue;
 
@@ -92,6 +95,9 @@ void CSettingsStore::SetLongParameter(int iParameter, long lValue) {
   // Check that the parameter is in fact in the right spot in the table
   DASHER_ASSERT(iParameter == s_oParamTables.LongParamTable[iParameter - FIRST_LP].key);
 
+  if(lValue == GetLongParameter(iParameter))
+    return;
+
   // Set the value
   s_oParamTables.LongParamTable[iParameter - FIRST_LP].value = lValue;
 
@@ -109,6 +115,9 @@ void CSettingsStore::SetStringParameter(int iParameter, const std::string sValue
   // Check that the parameter is in fact in the right spot in the table
   DASHER_ASSERT(iParameter == s_oParamTables.StringParamTable[iParameter - FIRST_SP].key);
 
+  if(sValue == GetStringParameter(iParameter))
+    return;
+
   // Set the value
   s_oParamTables.StringParamTable[iParameter - FIRST_SP].value = sValue;
 
@@ -156,6 +165,9 @@ void CSettingsStore::ResetParameter(int iParameter) {
   case ParamString:
     SetStringParameter(iParameter, stringparamtable[iParameter-FIRST_SP].defaultValue);
     break;
+  case ParamInvalid:
+    // TODO: Error handling?
+    break;
   }
 }
 
@@ -196,8 +208,12 @@ std::string CSettingsStore::GetParameterName(int iParameter)
       return s_oParamTables.StringParamTable[iParameter - FIRST_SP].regName;
       break;
     }
+  case ParamInvalid:
+    // TODO: Error handling?
+    break;
   };
 
+
   return "";
 }
 
@@ -205,7 +221,7 @@ std::string CSettingsStore::GetParameterName(int iParameter)
 ////////////////////////////////////////////////////////////
 //// DEPRECATED FUNCTIONS BELOW
 
-bool CSettingsStore::GetBoolOption(const string &Key) {
+bool CSettingsStore::GetBoolOption(const std::string &Key) {
   // Also make the call to the newer implementation
   for(int ii = 0; ii < NUM_OF_BPS; ii++) {
     if(s_oParamTables.BoolParamTable[ii].regName == Key) {
@@ -218,7 +234,7 @@ bool CSettingsStore::GetBoolOption(const string &Key) {
   return false;
 }
 
-long CSettingsStore::GetLongOption(const string &Key) {
+long CSettingsStore::GetLongOption(const std::string &Key) {
   for(int ii = 0; ii < NUM_OF_LPS; ii++) {
     if(s_oParamTables.LongParamTable[ii].regName == Key) {
       return GetLongParameter(s_oParamTables.LongParamTable[ii].key);
@@ -229,7 +245,7 @@ long CSettingsStore::GetLongOption(const string &Key) {
   return false;
 }
 
-string CSettingsStore::GetStringOption(const string &Key) {
+std::string CSettingsStore::GetStringOption(const std::string &Key) {
   // Also make the call to the newer implementation
   for(int ii = 0; ii < NUM_OF_SPS; ii++) {
     if(s_oParamTables.StringParamTable[ii].regName == Key) {
@@ -243,7 +259,7 @@ string CSettingsStore::GetStringOption(const string &Key) {
   return false;
 }
 
-void CSettingsStore::SetBoolOption(const string &Key, bool Value) {
+void CSettingsStore::SetBoolOption(const std::string &Key, bool Value) {
   // Also make the call to the newer implementation
   for(int ii = 0; ii < NUM_OF_BPS; ii++) {
     if(s_oParamTables.BoolParamTable[ii].regName == Key) {
@@ -256,7 +272,7 @@ void CSettingsStore::SetBoolOption(const string &Key, bool Value) {
   DASHER_ASSERT(0);
 }
 
-void CSettingsStore::SetLongOption(const string &Key, long Value) {
+void CSettingsStore::SetLongOption(const std::string &Key, long Value) {
   // Also make the call to the newer implementation
   for(int ii = 0; ii < NUM_OF_LPS; ii++) {
     if(s_oParamTables.LongParamTable[ii].regName == Key) {
@@ -269,7 +285,7 @@ void CSettingsStore::SetLongOption(const string &Key, long Value) {
   DASHER_ASSERT(0);
 }
 
-void CSettingsStore::SetStringOption(const string &Key, const string &Value) {
+void CSettingsStore::SetStringOption(const std::string &Key, const std::string &Value) {
   // Also make the call to the newer implementation
   for(int ii = 0; ii < NUM_OF_SPS; ii++) {
     if(s_oParamTables.StringParamTable[ii].regName == Key) {
@@ -286,23 +302,23 @@ void CSettingsStore::SetStringOption(const string &Key, const string &Value) {
 functions are over-ridden.
 --------------------------------------------------------------------------*/
 
-bool CSettingsStore::LoadSetting(const string &Key, bool *Value) {
+bool CSettingsStore::LoadSetting(const std::string &Key, bool *Value) {
   return false;
 }
 
-bool CSettingsStore::LoadSetting(const string &Key, long *Value) {
+bool CSettingsStore::LoadSetting(const std::string &Key, long *Value) {
   return false;
 }
 
-bool CSettingsStore::LoadSetting(const string &Key, string *Value) {
+bool CSettingsStore::LoadSetting(const std::string &Key, std::string *Value) {
   return false;
 }
 
-void CSettingsStore::SaveSetting(const string &Key, bool Value) {
+void CSettingsStore::SaveSetting(const std::string &Key, bool Value) {
 }
 
-void CSettingsStore::SaveSetting(const string &Key, long Value) {
+void CSettingsStore::SaveSetting(const std::string &Key, long Value) {
 }
 
-void CSettingsStore::SaveSetting(const string &Key, const string &Value) {
+void CSettingsStore::SaveSetting(const std::string &Key, const std::string &Value) {
 }
