@@ -53,9 +53,13 @@ void dasher_external_buffer_delete(DasherExternalBuffer *pSelf, int iLength);
 void dasher_external_buffer_edit_convert(DasherExternalBuffer *pSelf);
 void dasher_external_buffer_edit_protect(DasherExternalBuffer *pSelf);
 void dasher_external_buffer_conversion_mode(DasherExternalBuffer *pSelf, gboolean bMode);
-gchar *dasher_external_buffer_get_context(DasherExternalBuffer *pSelf, gint iMaxLength);
+gchar *dasher_external_buffer_get_context(DasherExternalBuffer *pSelf, gint iOffset, gint iLength);
 void dasher_external_buffer_edit_move(DasherExternalBuffer *pSelf, int iDirection, int iDist);
 void dasher_external_buffer_edit_delete(DasherExternalBuffer *pSelf, int iDirection, int iDist);
+gint dasher_external_buffer_get_offset(DasherExternalBuffer *pSelf) {
+  // TODO: Implement
+  return 0;
+}
 
 #ifdef GNOME_A11Y
 void dasher_external_buffer_handle_focus(DasherExternalBuffer *pSelf, const AccessibleEvent *pEvent);
@@ -123,12 +127,13 @@ static void idasher_buffer_set_interface_init (gpointer g_iface, gpointer iface_
   IDasherBufferSetInterface *iface = (IDasherBufferSetInterface *)g_iface;
   iface->insert_text = (void (*)(IDasherBufferSet *pSelf, const gchar *szText))dasher_external_buffer_insert;
   iface->delete_text = (void (*)(IDasherBufferSet *pSelf, gint iLength))dasher_external_buffer_delete;
-  iface->get_context = (gchar *(*)(IDasherBufferSet *pSelf, gint iMaxLength))dasher_external_buffer_get_context;
+  iface->get_context = (gchar *(*)(IDasherBufferSet *pSelf, gint iOffset, gint iLength))dasher_external_buffer_get_context;
   iface->edit_move = (void (*)(IDasherBufferSet *pSelf, gint iDirection, gint iDist))dasher_external_buffer_edit_move;
   iface->edit_delete = (void (*)(IDasherBufferSet *pSelf, gint iDirection, gint iDist))dasher_external_buffer_edit_delete;
   iface->edit_convert = (void (*)(IDasherBufferSet *pSelf))dasher_external_buffer_edit_convert;
   iface->edit_protect = (void (*)(IDasherBufferSet *pSelf))dasher_external_buffer_edit_protect;
   iface->conversion_mode = (void (*)(IDasherBufferSet *pSelf, gboolean bMode))dasher_external_buffer_conversion_mode;
+  iface->get_offset = (gint (*)(IDasherBufferSet *pSelf))dasher_external_buffer_get_offset;
 }
 
 static void dasher_external_buffer_destroy(GObject *pObject) {
@@ -288,22 +293,14 @@ void dasher_external_buffer_edit_delete(DasherExternalBuffer *pSelf, int iDirect
   // TODO: Implement
 }
 
-gchar *dasher_external_buffer_get_context(DasherExternalBuffer *pSelf, gint iMaxLength) {
+gchar *dasher_external_buffer_get_context(DasherExternalBuffer *pSelf, gint iOffset, gint iLength) {
 #ifdef GNOME_A11Y
   DasherExternalBufferPrivate *pPrivate = (DasherExternalBufferPrivate *)(pSelf->private_data);
 
-  if(pPrivate->pAccessibleText) {
-    int iOffset(AccessibleText_getCaretOffset(pPrivate->pAccessibleText));
-    int iStart(iOffset - iMaxLength);
-      
-    if(iStart < 0 )
-      iStart = 0;
-
-    return AccessibleText_getText(pPrivate->pAccessibleText, iOffset-iMaxLength, iOffset);
-  }
-  else {
+  if(pPrivate->pAccessibleText)
+    return AccessibleText_getText(pPrivate->pAccessibleText, iOffset, iOffset + iLength);
+  else
     return 0;
-  }
 #else
   return 0;
 #endif
@@ -337,7 +334,8 @@ void dasher_external_buffer_handle_focus(DasherExternalBuffer *pSelf, const Acce
 //     g_iExpectedPosition = AccessibleText_getCaretOffset(pPrivate->pAccessibleText);
 //     g_iOldPosition = g_iExpectedPosition;
 
-  g_signal_emit(pSelf, idasher_buffer_set_signals[CONTEXT_CHANGED], 0, NULL);
+    
+    g_signal_emit_by_name(G_OBJECT(pSelf), "context_changed", G_OBJECT(pSelf), NULL, NULL);
 
   }
 
